MediaFormats class

Annotations
  • @freezed

Constructors

MediaFormats({@FormatAttributeConvertor() required FormatAttributes thumbnail, @FormatAttributeConvertor() required FormatAttributes large, @FormatAttributeConvertor() required FormatAttributes medium, @FormatAttributeConvertor() required FormatAttributes small})
const
factory
MediaFormats.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $MediaFormatsCopyWith<MediaFormats>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
large FormatAttributes
no setterinherited
medium FormatAttributes
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small FormatAttributes
no setterinherited
thumbnail FormatAttributes
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited