StrapiPagination class

Annotations
  • @freezed

Constructors

StrapiPagination({int? total, int? pageCount, int? page, int? start, int? limit, int? pageSize})
const
factory
StrapiPagination.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $StrapiPaginationCopyWith<StrapiPagination>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
limit int?
no setterinherited
page int?
no setterinherited
pageCount int?
no setterinherited
pageSize int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int?
no setterinherited
total int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited